@@ -174,14 +174,13 @@ main (int argc, char **argv)
 {
   g_test_init (&argc, &argv, NULL);
 
-  g_test_add_data_func ("/pixbuf/scale/png", "test-images/valid_png_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/bmp", "test-images/valid_bmp_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/gif", "test-images/valid_gif_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/jpeg", "test-images/valid_jpeg_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/ras", "test-images/valid_ras_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/tga", "test-images/valid_tga_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/xpm", "test-images/valid_xpm_test", test_scale);
-  g_test_add_data_func ("/pixbuf/scale/xbm", "test-images/valid.xbm", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/png", "test-images/randomly-modified/valid.1.png", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/bmp", "test-images/randomly-modified/valid.1.bmp", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/gif", "test-images/randomly-modified/valid.1.gif", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/jpeg", "test-images/randomly-modified/valid.1.jpeg", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/tga", "test-images/randomly-modified/valid.1.tga", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/xpm", "test-images/randomly-modified/valid.1.xpm", test_scale);
+  g_test_add_data_func ("/pixbuf/scale/xbm", "test-images/randomly-modified/valid.1.xbm", test_scale);
   g_test_add_data_func ("/pixbuf/scale/png/large", "large.png", test_scale_down);
   g_test_add_data_func ("/pixbuf/scale/jpeg/large", "large.jpg", test_scale_down);
   g_test_add_data_func ("/pixbuf/add-alpha/large", "large.png", test_add_alpha);
